import { GoogleLogin as GoogleApiLogin, GoogleOAuthProvider } from '@react-oauth/google';
import { useNavigate } from 'react-router-dom';
import { useAuth } from '../../contexts/AuthContext';
import { GrantType } from '../../enums';
interface LoginProps {
  setError: (error: string) => void;
  setLoading: (loading: boolean) => void;
}
export const GoogleLogin = ({ setError, setLoading }: LoginProps) => {
  const { login } = useAuth();
  const navigate = useNavigate();

  const onError = (err: any) => {
    setError(err instanceof Error ? err.message : 'Login failed. Please check your credentials.');
  };

  const onSuccess = async (response: any) => {
    try {
      setLoading(true);
      await login({ grantType: GrantType.GOOGLE, googleToken: response.credential });
      navigate('/dashboard');
    } catch (error) {
      setError(error instanceof Error ? error.message : 'Login failed. Please check your credentials.');
    } finally {
      setLoading(false);
    }
  };
  return (
    <GoogleOAuthProvider clientId={process.env.GOOGLE_WEB_CLIENT_ID!}>
      <GoogleApiLogin
        onSuccess={(credentialResponse) => {
          onSuccess(credentialResponse);
        }}
        onError={() => {
          onError('Login failed. Please check your credentials.');
        }}
      />
    </GoogleOAuthProvider>
  );
};
