import {
  People as PeopleIcon,
  Assignment as TaskIcon,
  TrendingUp as TrendingUpIcon,
  AccountBalance as WalletIcon
} from '@mui/icons-material';
import {
  Box,
  Button,
  Card,
  CardContent,
  Grid,
  Paper,
  Typography,
  useTheme
} from '@mui/material';
import { useNavigate } from 'react-router-dom';

export const Dashboard = () => {
  const theme = useTheme();
  const navigate = useNavigate();

  const stats = [
    {
      title: 'Total Juniors',
      value: '3',
      icon: <PeopleIcon sx={{ fontSize: 40, color: 'primary.main' }} />,
      action: () => navigate('/juniors')
    },
    {
      title: 'Active Tasks',
      value: '5',
      icon: <TaskIcon sx={{ fontSize: 40, color: 'secondary.main' }} />,
      action: () => navigate('/tasks')
    },
    {
      title: 'Total Balance',
      value: 'SAR 500',
      icon: <WalletIcon sx={{ fontSize: 40, color: 'success.main' }} />,
      action: () => { }
    },
    {
      title: 'Monthly Growth',
      value: '+15%',
      icon: <TrendingUpIcon sx={{ fontSize: 40, color: 'info.main' }} />,
      action: () => { }
    }
  ];

  return (
    <Box>
      <Box sx={{ mb: 4 }}>
        <Typography variant="h4" sx={{ fontWeight: 600, color: 'text.primary', mb: 1 }}>
          Welcome to Zod Alkhair,
        </Typography>
        <Typography variant="body1" sx={{ color: 'text.secondary' }}>
          This is the API Testing client
        </Typography>
      </Box>

      <Grid container spacing={3} sx={{ mb: 4 }}>
        {stats.map((stat, index) => (
          <Grid item xs={12} sm={6} md={3} key={index}>
            <Card
              sx={{
                height: '100%',
                cursor: 'pointer',
                transition: 'transform 0.2s',
                '&:hover': {
                  transform: 'translateY(-4px)'
                }
              }}
              onClick={stat.action}
            >
              <CardContent>
                <Box sx={{ display: 'flex', alignItems: 'center', mb: 2 }}>
                  {stat.icon}
                </Box>
                <Typography variant="h5" sx={{ fontWeight: 600, mb: 1 }}>
                  {stat.value}
                </Typography>
                <Typography variant="body2" sx={{ color: 'text.secondary' }}>
                  {stat.title}
                </Typography>
              </CardContent>
            </Card>
          </Grid>
        ))}
      </Grid>

      <Grid container spacing={3}>
        <Grid item xs={12} md={8}>
          <Paper
            sx={{
              p: 3,
              height: '100%',
              backgroundColor: theme.palette.primary.main,
              color: 'white'
            }}
          >
            <Typography variant="h6" sx={{ mb: 2, fontWeight: 600 }}>
              Quick Actions
            </Typography>
            <Grid container spacing={2}>
              <Grid item xs={12} sm={6}>
                <Button
                  fullWidth
                  variant="contained"
                  sx={{
                    backgroundColor: 'rgba(255, 255, 255, 0.1)',
                    '&:hover': {
                      backgroundColor: 'rgba(255, 255, 255, 0.2)'
                    }
                  }}
                  onClick={() => navigate('/juniors/new')}
                >
                  Add New Junior
                </Button>
              </Grid>
              <Grid item xs={12} sm={6}>
                <Button
                  fullWidth
                  variant="contained"
                  sx={{
                    backgroundColor: 'rgba(255, 255, 255, 0.1)',
                    '&:hover': {
                      backgroundColor: 'rgba(255, 255, 255, 0.2)'
                    }
                  }}
                  onClick={() => navigate('/tasks/new')}
                >
                  Create New Task
                </Button>
              </Grid>
            </Grid>
          </Paper>
        </Grid>
        <Grid item xs={12} md={4}>
          <Paper sx={{ p: 3, height: '100%' }}>
            <Typography variant="h6" sx={{ mb: 2, fontWeight: 600 }}>
              Recent Activity
            </Typography>
            <Typography variant="body2" color="text.secondary" sx={{ textAlign: 'center', mt: 4 }}>
              No recent activity
            </Typography>
          </Paper>
        </Grid>
      </Grid>
    </Box>
  );
};
