import { Box, Card, CardContent, Chip, CircularProgress, Typography } from '@mui/material';
import { useEffect, useState } from 'react';
import { useNavigate, useParams } from 'react-router-dom';
import { tasksApi } from '../../api/client';
import { Task } from '../../types/task';

export const TaskDetails = () => {
  useNavigate();
  const [loading, setLoading] = useState(false);
  const [error, setError] = useState('');
  const statusColors = {
    PENDING: 'warning',
    IN_PROGRESS: 'info',
    COMPLETED: 'success',
  } as const;

  const { taskId } = useParams();
  if (!taskId) {
    throw new Error('Task ID is required');
  }
  const [task, setTask] = useState<Task>();
  const fetchTask = async () => {
    try {
      setLoading(true);
      const response = await tasksApi.getTaskById(taskId);
      setTask(response.data.data);
    } catch (err) {
      setError(err instanceof Error ? err.message : 'Failed to load task');
    } finally {
      setLoading(false);
    }
  };

  useEffect(() => {
    fetchTask();
  }, []);

  if (loading) {
    return (
      <Box display="flex" justifyContent="center" alignItems="center" minHeight="200px">
        <CircularProgress />
      </Box>
    );
  }

  if (error) {
    return (
      <Box p={3}>
        <Typography color="error">{error}</Typography>
      </Box>
    );
  }

  if (!task) {
    return (
      <Box p={3}>
        <Typography color="error">Task not found</Typography>
      </Box>
    );
  }
  console.log(task);

  return (
    <Card>
      <CardContent>
        <Box display="flex" justifyContent="space-between" alignItems="flex-start">
          <Typography variant="h6" gutterBottom>
            {task.title}
          </Typography>
          <Chip label={task.status} color={statusColors[task.status]} size="small" />
        </Box>
        <Typography color="textSecondary" gutterBottom>
          Due: {new Date(task.dueDate).toLocaleDateString()}
        </Typography>
        <Typography variant="body2" gutterBottom>
          {task.description}
        </Typography>
        <Typography color="primary" gutterBottom>
          Reward: ${task.rewardAmount}
        </Typography>
        <Typography variant="body2" color="textSecondary">
          Assigned to: {task.junior.fullName}
        </Typography>
      </CardContent>
    </Card>
  );
};
