import { ApiProperty } from '@nestjs/swagger';
import { IsNotEmpty, IsNumber, IsPositive, IsString, IsUUID } from 'class-validator';
import { i18nValidationMessage as i18n } from 'nestjs-i18n';

export class CreateAllowanceChangeRequestDto {
  @ApiProperty({ example: 'I want to change the amount of the allowance' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'allowanceChangeRequest.reason' }) })
  @IsNotEmpty({
    message: i18n('validation.IsNotEmpty', { path: 'general', property: 'allowanceChangeRequest.reason' }),
  })
  reason!: string;

  @ApiProperty({ example: 100 })
  @IsNumber(
    {},
    { message: i18n('validation.IsNumber', { path: 'general', property: 'allowanceChangeRequest.amount' }) },
  )
  @IsPositive({
    message: i18n('validation.IsPositive', { path: 'general', property: 'allowanceChangeRequest.amount' }),
  })
  amount!: number;

  @ApiProperty({ example: 'd641bb71-2e7c-4e62-96fa-2785f0a651c6' })
  @IsUUID('4', {
    message: i18n('validation.IsUUID', { path: 'general', property: 'allowanceChangeRequest.allowanceId' }),
  })
  allowanceId!: string;
}
