import { Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { FindOptionsWhere, Repository } from 'typeorm';
import { PageOptionsRequestDto } from '~/core/dtos';
import { CreateAllowanceChangeRequestDto } from '../dtos/request';
import { AllowanceChangeRequest } from '../entities';
import { AllowanceChangeRequestStatus } from '../enums';
const ONE = 1;
@Injectable()
export class AllowanceChangeRequestsRepository {
  constructor(
    @InjectRepository(AllowanceChangeRequest)
    private readonly allowanceChangeRequestsRepository: Repository<AllowanceChangeRequest>,
  ) {}

  createAllowanceChangeRequest(allowanceId: string, body: CreateAllowanceChangeRequestDto) {
    return this.allowanceChangeRequestsRepository.save(
      this.allowanceChangeRequestsRepository.create({
        allowanceId,
        amount: body.amount,
        reason: body.reason,
      }),
    );
  }

  findAllowanceChangeRequestBy(where: FindOptionsWhere<AllowanceChangeRequest>, withRelations = false) {
    const relations = withRelations
      ? ['allowance', 'allowance.junior', 'allowance.junior.customer', 'allowance.junior.customer.profilePicture']
      : [];
    return this.allowanceChangeRequestsRepository.findOne({ where, relations });
  }

  updateAllowanceChangeRequestStatus(requestId: string, status: AllowanceChangeRequestStatus) {
    return this.allowanceChangeRequestsRepository.update({ id: requestId }, { status });
  }

  findAllowanceChangeRequests(guardianId: string, query: PageOptionsRequestDto) {
    return this.allowanceChangeRequestsRepository.findAndCount({
      where: { allowance: { guardianId } },
      take: query.size,
      skip: query.size * (query.page - ONE),
      relations: [
        'allowance',
        'allowance.junior',
        'allowance.junior.customer',
        'allowance.junior.customer.profilePicture',
      ],
    });
  }
}
