import { ApiProperty } from '@nestjs/swagger';
import { IsEmail, IsEnum, IsNotEmpty, IsOptional, IsString, ValidateIf } from 'class-validator';
import { i18nValidationMessage as i18n } from 'nestjs-i18n';
import { GrantType } from '~/auth/enums';
export class LoginRequestDto {
  @ApiProperty({ example: GrantType.PASSWORD })
  @IsEnum(GrantType, { message: i18n('validation.IsEnum', { path: 'general', property: 'auth.grantType' }) })
  grantType!: GrantType;

  @ApiProperty({ example: 'test@test.com' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'auth.email' }) })
  @IsEmail({}, { message: i18n('validation.IsEmail', { path: 'general', property: 'auth.email' }) })
  @ValidateIf((o) => o.grantType !== GrantType.APPLE && o.grantType !== GrantType.GOOGLE)
  email!: string;

  @ApiProperty({ example: '123456' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'auth.password' }) })
  @ValidateIf((o) => o.grantType === GrantType.PASSWORD)
  password!: string;

  @ApiProperty({ example: 'Login signature' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'auth.signature' }) })
  @ValidateIf((o) => o.grantType === GrantType.BIOMETRIC)
  signature!: string;

  @ApiProperty({ example: 'google_token' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'auth.googleToken' }) })
  @IsNotEmpty({ message: i18n('validation.IsNotEmpty', { path: 'general', property: 'auth.googleToken' }) })
  @ValidateIf((o) => o.grantType === GrantType.GOOGLE)
  googleToken!: string;

  @ApiProperty({ example: 'apple_token' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'auth.appleToken' }) })
  @IsNotEmpty({ message: i18n('validation.IsNotEmpty', { path: 'general', property: 'auth.appleToken' }) })
  @ValidateIf((o) => o.grantType === GrantType.APPLE)
  appleToken!: string;

  @ApiProperty({ example: 'fcm-device-token' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'auth.fcmToken' }) })
  @IsNotEmpty({ message: i18n('validation.IsNotEmpty', { path: 'general', property: 'auth.fcmToken' }) })
  @IsOptional()
  fcmToken?: string;
}
