import { Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Repository } from 'typeorm';
import { PageOptionsRequestDto } from '~/core/dtos';
import { Notification } from '../entities';
import { NotificationChannel, NotificationStatus } from '../enums';
const ONE = 1;
@Injectable()
export class NotificationsRepository {
  constructor(@InjectRepository(Notification) private readonly notificationsRepository: Repository<Notification>) {}

  getNotifications(userId: string, pageOptionsDto: PageOptionsRequestDto) {
    const readQuery = this.notificationsRepository.createQueryBuilder('notification');
    readQuery.where('notification.userId = :userId', { userId });
    readQuery.andWhere('notification.channel = :channel', { channel: NotificationChannel.PUSH });
    readQuery.orderBy('notification.createdAt', 'DESC');
    readQuery.skip((pageOptionsDto.page - ONE) * pageOptionsDto.size);
    readQuery.take(pageOptionsDto.size);
    return readQuery.getManyAndCount();
  }

  getUnreadNotificationsCount(userId: string) {
    return this.notificationsRepository.count({ where: { userId, status: NotificationStatus.UNREAD } });
  }

  markAsRead(userId: string) {
    return this.notificationsRepository.update(
      { userId, status: NotificationStatus.UNREAD },
      { status: NotificationStatus.READ },
    );
  }

  createNotification(notification: Partial<Notification>) {
    return this.notificationsRepository.save(notification);
  }
}
