import { Body, Controller, Get, Patch, Post, UseGuards } from '@nestjs/common';
import { ApiBearerAuth, ApiTags } from '@nestjs/swagger';
import { IJwtPayload } from '~/auth/interfaces';
import { AuthenticatedUser } from '~/common/decorators';
import { AccessTokenGuard } from '~/common/guards';
import { ApiDataResponse, ApiLangRequestHeader } from '~/core/decorators';
import { ResponseFactory } from '~/core/utils';
import { CreateCustomerRequestDto, UpdateCustomerRequestDto } from '../dtos/request';
import { CustomerResponseDto } from '../dtos/response';
import { CustomerService } from '../services';

@Controller('customers')
@ApiTags('Customers')
@ApiBearerAuth()
@ApiLangRequestHeader()
export class CustomerController {
  constructor(private readonly customerService: CustomerService) {}

  @Get('/profile')
  @UseGuards(AccessTokenGuard)
  @ApiDataResponse(CustomerResponseDto)
  async getCustomerProfile(@AuthenticatedUser() { sub }: IJwtPayload) {
    const customer = await this.customerService.findCustomerById(sub);

    return ResponseFactory.data(new CustomerResponseDto(customer));
  }

  @Patch()
  @UseGuards(AccessTokenGuard)
  @ApiDataResponse(CustomerResponseDto)
  async updateCustomer(@AuthenticatedUser() { sub }: IJwtPayload, @Body() body: UpdateCustomerRequestDto) {
    const customer = await this.customerService.updateCustomer(sub, body);

    return ResponseFactory.data(new CustomerResponseDto(customer));
  }

  @Post('')
  @UseGuards(AccessTokenGuard)
  @ApiDataResponse(CustomerResponseDto)
  async createCustomer(@AuthenticatedUser() { sub }: IJwtPayload, @Body() body: CreateCustomerRequestDto) {
    const customer = await this.customerService.createGuardianCustomer(sub, body);

    return ResponseFactory.data(new CustomerResponseDto(customer));
  }
}
