import { Body, Controller, Get, HttpCode, HttpStatus, Param, Patch, Query } from '@nestjs/common';
import { ApiTags } from '@nestjs/swagger';
import { CustomParseUUIDPipe } from '~/core/pipes';
import { ResponseFactory } from '~/core/utils';
import { CustomerFiltersRequestDto, RejectCustomerKycRequestDto } from '../dtos/request';
import { InternalCustomerDetailsResponseDto } from '../dtos/response';
import { InternalCustomerListResponse } from '../dtos/response/internal.customer-list.response.dto';
import { CustomerService } from '../services';

@ApiTags('Customers')
@Controller('internal/customers')
export class InternalCustomerController {
  constructor(private readonly customerService: CustomerService) {}
  @Get()
  async findCustomers(@Query() filters: CustomerFiltersRequestDto) {
    const [customers, count] = await this.customerService.findCustomers(filters);

    return ResponseFactory.dataPage(
      customers.map((customer) => new InternalCustomerListResponse(customer)),
      {
        page: filters.page,
        size: filters.size,
        itemCount: count,
      },
    );
  }

  @Get(':customerId')
  async findCustomerById(@Param('customerId', CustomParseUUIDPipe) customerId: string) {
    const customer = await this.customerService.findInternalCustomerById(customerId);

    return ResponseFactory.data(new InternalCustomerDetailsResponseDto(customer));
  }

  @Patch(':customerId/approve')
  @HttpCode(HttpStatus.NO_CONTENT)
  async approveKycForCustomer(@Param('customerId', CustomParseUUIDPipe) customerId: string) {
    await this.customerService.approveKycForCustomer(customerId);
  }

  @Patch(':customerId/reject')
  @HttpCode(HttpStatus.NO_CONTENT)
  async rejectKycForCustomer(
    @Param('customerId', CustomParseUUIDPipe) customerId: string,
    @Body() body: RejectCustomerKycRequestDto,
  ) {
    await this.customerService.rejectKycForCustomer(customerId, body);
  }
}
