import { ApiProperty } from '@nestjs/swagger';
import { IsBoolean, IsDateString, IsEnum, IsNotEmpty, IsString, IsUUID } from 'class-validator';
import { i18nValidationMessage as i18n } from 'nestjs-i18n';
import { IsAbove18 } from '~/core/decorators/validations';
import { Gender } from '~/customer/enums';
export class CreateCustomerRequestDto {
  @ApiProperty({ example: 'John' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'customer.firstName' }) })
  @IsNotEmpty({ message: i18n('validation.IsNotEmpty', { path: 'general', property: 'customer.firstName' }) })
  firstName!: string;

  @ApiProperty({ example: 'Doe' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'customer.lastName' }) })
  @IsNotEmpty({ message: i18n('validation.IsNotEmpty', { path: 'general', property: 'customer.lastName' }) })
  lastName!: string;

  @ApiProperty({ example: 'MALE' })
  @IsEnum(Gender, { message: i18n('validation.IsEnum', { path: 'general', property: 'customer.gender' }) })
  gender!: Gender;

  @ApiProperty({ example: 'JO' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'customer.countryOfResidence' }) })
  @IsNotEmpty({ message: i18n('validation.IsNotEmpty', { path: 'general', property: 'customer.countryOfResidence' }) })
  countryOfResidence!: string;

  @ApiProperty({ example: '2021-01-01' })
  @IsDateString({}, { message: i18n('validation.IsDateString', { path: 'general', property: 'customer.dateOfBirth' }) })
  @IsAbove18({ message: i18n('validation.IsAbove18', { path: 'general', property: 'customer.dateOfBirth' }) })
  dateOfBirth!: Date;

  @ApiProperty({ example: '999300024' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'customer.nationalId' }) })
  @IsNotEmpty({ message: i18n('validation.IsNotEmpty', { path: 'general', property: 'customer.nationalId' }) })
  nationalId!: string;

  @ApiProperty({ example: '2021-01-01' })
  @IsDateString(
    {},
    { message: i18n('validation.IsDateString', { path: 'general', property: 'junior.nationalIdExpiry' }) },
  )
  nationalIdExpiry!: Date;

  @ApiProperty({ example: 'Employee' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'customer.sourceOfIncome' }) })
  @IsNotEmpty({ message: i18n('validation.IsNotEmpty', { path: 'general', property: 'customer.sourceOfIncome' }) })
  sourceOfIncome!: string;

  @ApiProperty({ example: 'Accountant' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'customer.profession' }) })
  @IsNotEmpty({ message: i18n('validation.IsNotEmpty', { path: 'general', property: 'customer.profession' }) })
  profession!: string;

  @ApiProperty({ example: 'Finance' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'customer.professionType' }) })
  @IsNotEmpty({ message: i18n('validation.IsNotEmpty', { path: 'general', property: 'customer.professionType' }) })
  professionType!: string;

  @ApiProperty({ example: false })
  @IsBoolean({ message: i18n('validation.IsBoolean', { path: 'general', property: 'junior.isPep' }) })
  isPep!: boolean;

  @ApiProperty({ example: 'bf342-3f3f-3f3f-3f3f' })
  @IsUUID('4', { message: i18n('validation.IsUUID', { path: 'general', property: 'junior.civilIdFrontId' }) })
  civilIdFrontId!: string;

  @ApiProperty({ example: 'bf342-3f3f-3f3f-3f3f' })
  @IsUUID('4', { message: i18n('validation.IsUUID', { path: 'general', property: 'junior.civilIdBackId' }) })
  civilIdBackId!: string;
}
