import { ApiPropertyOptional } from '@nestjs/swagger';
import { IsEnum, IsNotEmpty, IsOptional, IsString } from 'class-validator';
import { i18nValidationMessage as i18n } from 'nestjs-i18n';
import { PageOptionsRequestDto } from '~/core/dtos';
import { KycStatus } from '~/customer/enums';

export class CustomerFiltersRequestDto extends PageOptionsRequestDto {
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'customer.name' }) })
  @IsNotEmpty({ message: i18n('validation.IsNotEmpty', { path: 'general', property: 'customer.name' }) })
  @IsOptional()
  @ApiPropertyOptional({ description: 'search by name' })
  name?: string;

  @IsEnum(KycStatus, { message: i18n('validation.IsEnum', { path: 'general', property: 'customer.kycStatus' }) })
  @IsOptional()
  @ApiPropertyOptional({
    enum: KycStatus,
    enumName: 'KycStatus',
    example: KycStatus.PENDING,
    description: 'kyc status of the customer',
  })
  kycStatus?: string;
}
