import { MigrationInterface, QueryRunner } from 'typeorm';

export class CreateAllowanceEntities1734601976591 implements MigrationInterface {
  name = 'CreateAllowanceEntities1734601976591';

  public async up(queryRunner: QueryRunner): Promise<void> {
    await queryRunner.query(
      `CREATE TABLE "allowances" 
      ("id" uuid NOT NULL DEFAULT uuid_generate_v4(), 
      "name" character varying(255) NOT NULL, 
      "amount" numeric(10,2) NOT NULL, 
      "frequency" character varying(255) NOT NULL, 
      "type" character varying(255) NOT NULL, 
      "start_date" TIMESTAMP WITH TIME ZONE NOT NULL, 
      "end_date" TIMESTAMP WITH TIME ZONE, 
      "number_of_transactions" integer, 
      "guardian_id" uuid NOT NULL, 
      "junior_id" uuid NOT NULL, 
      "created_at" TIMESTAMP WITH TIME ZONE NOT NULL DEFAULT now(), 
      "updated_at" TIMESTAMP WITH TIME ZONE NOT NULL DEFAULT now(), 
      "deleted_at" TIMESTAMP WITH TIME ZONE, 
      CONSTRAINT "PK_3731e781e7c4e932ba4d4213ac1" PRIMARY KEY ("id"))`,
    );
    await queryRunner.query(
      `CREATE TABLE "allowance_change_requests" 
      ("id" uuid NOT NULL DEFAULT uuid_generate_v4(), 
      "reason" text NOT NULL, 
      "amount" numeric(10,2) NOT NULL, 
      "status" character varying(255) NOT NULL DEFAULT 'PENDING', 
      "allowance_id" uuid NOT NULL, 
      "created_at" TIMESTAMP WITH TIME ZONE NOT NULL DEFAULT now(), 
      "updated_at" TIMESTAMP WITH TIME ZONE NOT NULL DEFAULT now(), 
      CONSTRAINT "PK_664715670e1e72c64ce65a078de" PRIMARY KEY ("id"))`,
    );
    await queryRunner.query(
      `ALTER TABLE "allowances" ADD CONSTRAINT "FK_80b144a74e630ed63311e97427b" FOREIGN KEY ("guardian_id") REFERENCES "guardians"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`,
    );
    await queryRunner.query(
      `ALTER TABLE "allowances" ADD CONSTRAINT "FK_61e6e612f6d4644f8910d453cc9" FOREIGN KEY ("junior_id") REFERENCES "juniors"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`,
    );
    await queryRunner.query(
      `ALTER TABLE "allowance_change_requests" ADD CONSTRAINT "FK_4ea6382927f50cb93873fae16d2" FOREIGN KEY ("allowance_id") REFERENCES "allowances"("id") ON DELETE NO ACTION ON UPDATE NO ACTION`,
    );
  }

  public async down(queryRunner: QueryRunner): Promise<void> {
    await queryRunner.query(`ALTER TABLE "allowance_change_requests" DROP CONSTRAINT "FK_4ea6382927f50cb93873fae16d2"`);
    await queryRunner.query(`ALTER TABLE "allowances" DROP CONSTRAINT "FK_61e6e612f6d4644f8910d453cc9"`);
    await queryRunner.query(`ALTER TABLE "allowances" DROP CONSTRAINT "FK_80b144a74e630ed63311e97427b"`);
    await queryRunner.query(`DROP TABLE "allowance_change_requests"`);
    await queryRunner.query(`DROP TABLE "allowances"`);
  }
}
