import { Injectable, Logger } from '@nestjs/common';
import { FindOptionsWhere } from 'typeorm';
import { UploadDocumentRequestDto } from '../dtos/request';
import { Document } from '../entities';
import { DocumentRepository } from '../repositories';
import { OciService } from './oci.service';

@Injectable()
export class DocumentService {
  private readonly logger = new Logger(DocumentService.name);
  constructor(private readonly ociService: OciService, private readonly documentRepository: DocumentRepository) {}
  async createDocument(file: Express.Multer.File, uploadedDocumentRequest: UploadDocumentRequestDto, userId: string) {
    this.logger.log(`creating document for with type ${uploadedDocumentRequest.documentType}`);
    const uploadedFile = await this.ociService.uploadFile(file, uploadedDocumentRequest);
    return this.documentRepository.createDocument(userId, uploadedFile);
  }

  findDocuments(where: FindOptionsWhere<Document>) {
    this.logger.log(`finding documents with where clause ${JSON.stringify(where)}`);
    return this.documentRepository.findDocuments(where);
  }

  findDocumentById(id: string) {
    this.logger.log(`finding document with id ${id}`);
    return this.documentRepository.findDocumentById(id);
  }
}
