import { ApiProperty } from '@nestjs/swagger';
import { IsDateString, IsEmail, IsEnum, IsNotEmpty, IsString, IsUUID, Matches } from 'class-validator';
import { i18nValidationMessage as i18n } from 'nestjs-i18n';
import { COUNTRY_CODE_REGEX } from '~/auth/constants';
import { IsValidPhoneNumber } from '~/core/decorators/validations';
import { Gender } from '~/customer/enums';
import { Relationship } from '~/junior/enums';
export class CreateJuniorRequestDto {
  @ApiProperty({ example: '+962' })
  @Matches(COUNTRY_CODE_REGEX, {
    message: i18n('validation.Matches', { path: 'general', property: 'auth.countryCode' }),
  })
  countryCode: string = '+966';

  @ApiProperty({ example: '787259134' })
  @IsValidPhoneNumber({
    message: i18n('validation.IsValidPhoneNumber', { path: 'general', property: 'auth.phoneNumber' }),
  })
  phoneNumber!: string;

  @ApiProperty({ example: 'John' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'customer.firstName' }) })
  @IsNotEmpty({ message: i18n('validation.IsNotEmpty', { path: 'general', property: 'customer.firstName' }) })
  firstName!: string;

  @ApiProperty({ example: 'Doe' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'customer.lastName' }) })
  @IsNotEmpty({ message: i18n('validation.IsNotEmpty', { path: 'general', property: 'customer.lastName' }) })
  lastName!: string;

  @ApiProperty({ example: 'MALE' })
  @IsEnum(Gender, { message: i18n('validation.IsEnum', { path: 'general', property: 'customer.gender' }) })
  gender!: string;

  @ApiProperty({ example: '2020-01-01' })
  @IsDateString({}, { message: i18n('validation.IsDateString', { path: 'general', property: 'customer.dateOfBirth' }) })
  dateOfBirth!: Date;

  @ApiProperty({ example: 'test@test.com' })
  @IsEmail({}, { message: i18n('validation.IsEmail', { path: 'general', property: 'auth.email' }) })
  email!: string;

  @ApiProperty({ example: Relationship.PARENT })
  @IsEnum(Relationship, { message: i18n('validation.IsEnum', { path: 'general', property: 'junior.relationship' }) })
  relationship!: Relationship;

  @ApiProperty({ example: 'bf342-3f3f-3f3f-3f3f' })
  @IsUUID('4', { message: i18n('validation.IsUUID', { path: 'general', property: 'junior.civilIdFrontId' }) })
  civilIdFrontId!: string;

  @ApiProperty({ example: 'bf342-3f3f-3f3f-3f3f' })
  @IsUUID('4', { message: i18n('validation.IsUUID', { path: 'general', property: 'junior.civilIdBackId' }) })
  civilIdBackId!: string;
}
