import {
  BaseEntity,
  Column,
  CreateDateColumn,
  Entity,
  JoinColumn,
  ManyToOne,
  OneToMany,
  OneToOne,
  PrimaryColumn,
  UpdateDateColumn,
} from 'typeorm';
import { Allowance } from '~/allowance/entities';
import { Customer } from '~/customer/entities';
import { Gift } from '~/gift/entities';
import { Guardian } from '~/guardian/entities/guradian.entity';
import { MoneyRequest } from '~/money-request/entities';
import { Category, SavingGoal } from '~/saving-goals/entities';
import { Task } from '~/task/entities';
import { UserRegistrationToken } from '~/user/entities';
import { Relationship } from '../enums';
import { Theme } from './theme.entity';

@Entity('juniors')
export class Junior extends BaseEntity {
  @PrimaryColumn('uuid')
  id!: string;

  @Column('varchar', { length: 255 })
  relationship!: Relationship;

  @Column('uuid', { name: 'customer_id' })
  customerId!: string;

  @Column('uuid', { name: 'guardian_id' })
  guardianId!: string;

  @OneToOne(() => Customer, (customer) => customer.junior, { onDelete: 'CASCADE' })
  @JoinColumn({ name: 'customer_id' })
  customer!: Customer;

  @OneToOne(() => Theme, (theme) => theme.junior, { cascade: true, nullable: true })
  theme!: Theme;

  @ManyToOne(() => Guardian, (guardian) => guardian.juniors)
  @JoinColumn({ name: 'guardian_id' })
  guardian!: Guardian;

  @OneToMany(() => Task, (task) => task.assignedTo)
  tasks!: Task[];

  @OneToMany(() => SavingGoal, (savingGoal) => savingGoal.junior)
  goals!: SavingGoal[];

  @OneToMany(() => Category, (category) => category.junior)
  categories!: Category[];

  @OneToMany(() => UserRegistrationToken, (token) => token.junior)
  registrationTokens!: UserRegistrationToken[];

  @OneToMany(() => MoneyRequest, (moneyRequest) => moneyRequest.requester)
  moneyRequests!: MoneyRequest[];

  @OneToMany(() => Allowance, (allowance) => allowance.junior)
  allowances!: Allowance[];

  @OneToMany(() => Gift, (gift) => gift.recipient)
  gifts!: Gift[];

  @CreateDateColumn({ name: 'created_at', type: 'timestamp', default: () => 'CURRENT_TIMESTAMP' })
  createdAt!: Date;

  @UpdateDateColumn({ name: 'updated_at', type: 'timestamp', default: () => 'CURRENT_TIMESTAMP' })
  updatedAt!: Date;
}
