import { Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { In, Repository } from 'typeorm';
import { createCategoryRequestDto } from '../dtos/request';
import { Category } from '../entities';
import { CategoryType } from '../enums';

@Injectable()
export class CategoryRepository {
  constructor(@InjectRepository(Category) private categoryRepository: Repository<Category>) {}

  createCustomCategory(juniorId: string, body: createCategoryRequestDto): Promise<Category> {
    return this.categoryRepository.save(
      this.categoryRepository.create({
        juniorId,
        name: body.name,
        type: CategoryType.CUSTOM,
      }),
    );
  }

  findCategoryById(ids: string[], juniorId: string): Promise<Category[]> {
    return this.categoryRepository.find({
      where: [
        { id: In(ids), type: CategoryType.GLOBAL },
        { id: In(ids), juniorId, type: CategoryType.CUSTOM },
      ],
    });
  }

  findCategories(juniorId: string): Promise<Category[]> {
    return this.categoryRepository.find({
      where: [{ type: 'GLOBAL' }, { juniorId, type: CategoryType.CUSTOM }],
    });
  }
}
