import { Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Repository } from 'typeorm';
import { PageOptionsRequestDto } from '~/core/dtos';
import { CreateGoalRequestDto } from '../dtos/request';
import { Category, SavingGoal } from '../entities';
const ONE = 1;
@Injectable()
export class SavingGoalsRepository {
  constructor(@InjectRepository(SavingGoal) private readonly savingGoalRepository: Repository<SavingGoal>) {}

  createGoal(juniorId: string, body: CreateGoalRequestDto, categories: Category[]) {
    return this.savingGoalRepository.save(
      this.savingGoalRepository.create({
        name: body.name,
        description: body.description,
        dueDate: body.dueDate,
        targetAmount: body.targetAmount,
        juniorId,
        imageId: body.imageId,
        categories,
      }),
    );
  }

  findGoals(juniorId: string, pageOptions: PageOptionsRequestDto) {
    return this.savingGoalRepository.findAndCount({
      where: { juniorId },
      take: pageOptions.size,
      skip: pageOptions.size * (pageOptions.page - ONE),
      relations: ['categories', 'image'],
    });
  }

  findGoalById(juniorId: string, goalId: string) {
    return this.savingGoalRepository.findOneOrFail({
      where: { juniorId, id: goalId },
      relations: ['categories', 'image'],
    });
  }

  fundGoal(juniorId: string, goalId: string, amount: number) {
    return this.savingGoalRepository.increment({ juniorId, id: goalId }, 'currentAmount', amount);
  }

  getStats(juniorId: string) {
    return this.savingGoalRepository
      .createQueryBuilder('savingGoal')
      .select('SUM(savingGoal.currentAmount)', 'totalSaved')
      .addSelect('SUM(savingGoal.targetAmount)', 'totalTarget')
      .where('savingGoal.juniorId = :juniorId', { juniorId })
      .getRawOne();
  }
}
