import { BadRequestException, Injectable, Logger } from '@nestjs/common';
import { createCategoryRequestDto } from '../dtos/request';
import { Category } from '../entities';
import { CategoryType } from '../enums';
import { CategoryRepository } from '../repositories';

@Injectable()
export class CategoryService {
  private readonly logger = new Logger(CategoryService.name);
  constructor(private readonly categoryRepository: CategoryRepository) {}

  createCustomCategory(juniorId: string, body: createCategoryRequestDto) {
    this.logger.log(`Creating custom category for junior ${juniorId}`);
    return this.categoryRepository.createCustomCategory(juniorId, body);
  }

  async findCategoryByIds(categoryIds: string[], juniorId: string) {
    this.logger.log(`Finding categories by ids for junior ${juniorId} with ids ${categoryIds}`);
    const categories = await this.categoryRepository.findCategoryById(categoryIds, juniorId);

    if (categories.length !== categoryIds.length) {
      this.logger.error(`Invalid category ids ${categoryIds}`);
      throw new BadRequestException('CATEGORY.INVALID_CATEGORY_ID');
    }

    this.logger.log(`Categories found successfully for junior ${juniorId}`);
    return categories;
  }

  async findCategories(juniorId: string): Promise<{ globalCategories: Category[]; customCategories: Category[] }> {
    this.logger.log(`Finding categories for junior ${juniorId}`);
    const categories = await this.categoryRepository.findCategories(juniorId);

    const globalCategories = categories.filter((category) => category.type === CategoryType.GLOBAL);
    const customCategories = categories.filter((category) => category.type === CategoryType.CUSTOM);

    this.logger.log(`Returning categories for junior ${juniorId}`);
    return {
      globalCategories,
      customCategories,
    };
  }
}
