import { Body, Controller, Get, Param, Post, Query, UseGuards } from '@nestjs/common';
import { ApiBearerAuth, ApiTags } from '@nestjs/swagger';
import { UserResponseDto } from '~/auth/dtos/response';
import { Roles } from '~/auth/enums';
import { AllowedRoles } from '~/common/decorators';
import { RolesGuard } from '~/common/guards';
import { ApiDataPageResponse, ApiDataResponse } from '~/core/decorators';
import { CustomParseUUIDPipe } from '~/core/pipes';
import { ResponseFactory } from '~/core/utils';
import { CreateCheckerRequestDto, UserFiltersRequestDto } from '../dtos/request';
import { UserService } from '../services';

@Controller('admin/users')
@ApiTags('Users')
@UseGuards(RolesGuard)
@AllowedRoles(Roles.SUPER_ADMIN)
@ApiBearerAuth()
export class AdminUserController {
  constructor(private readonly userService: UserService) {}
  @Post()
  @ApiDataResponse(UserResponseDto)
  async createCheckers(@Body() data: CreateCheckerRequestDto) {
    const user = await this.userService.createChecker(data);

    return ResponseFactory.data(new UserResponseDto(user));
  }

  @Get()
  @ApiDataPageResponse(UserResponseDto)
  async findUsers(@Query() filters: UserFiltersRequestDto) {
    const [users, count] = await this.userService.findUsers(filters);

    return ResponseFactory.dataPage(
      users.map((user) => new UserResponseDto(user)),
      {
        page: filters.page,
        size: filters.size,
        itemCount: count,
      },
    );
  }

  @Get(':userId')
  @ApiDataResponse(UserResponseDto)
  async findUserById(@Param('userId', CustomParseUUIDPipe) userId: string) {
    const user = await this.userService.findUserOrThrow({ id: userId });

    return ResponseFactory.data(new UserResponseDto(user));
  }
}
