import { ApiPropertyOptional } from '@nestjs/swagger';
import { IsEnum, IsNotEmpty, IsOptional, IsString } from 'class-validator';
import { i18nValidationMessage as i18n } from 'nestjs-i18n';
import { Roles } from '~/auth/enums';
import { PageOptionsRequestDto } from '~/core/dtos';

export class UserFiltersRequestDto extends PageOptionsRequestDto {
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'user.search' }) })
  @IsNotEmpty({ message: i18n('validation.IsNotEmpty', { path: 'general', property: 'user.search' }) })
  @IsOptional()
  @ApiPropertyOptional({ description: 'Search by email or phone number' })
  search?: string;

  @IsEnum(Roles, { message: i18n('validation.IsEnum', { path: 'general', property: 'user.role' }) })
  @IsOptional()
  @ApiPropertyOptional({ enum: Roles, enumName: 'Roles', example: Roles.CHECKER, description: 'Role of the user' })
  role?: string;
}
