import { Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import * as crypto from 'crypto';
import moment from 'moment';
import { Repository } from 'typeorm';
import { UserRegistrationToken } from '../entities';
import { UserType } from '../enums';
const TOKEN_LENGTH = 16;

@Injectable()
export class UserTokenRepository {
  constructor(
    @InjectRepository(UserRegistrationToken)
    private readonly userTokenRepository: Repository<UserRegistrationToken>,
  ) {}

  generateToken(userId: string, userType: UserType, expiryDate?: Date) {
    return this.userTokenRepository.save(
      this.userTokenRepository.create({
        userId: userType === UserType.CHECKER ? userId : null,
        juniorId: userType === UserType.JUNIOR ? userId : null,
        expiryDate: expiryDate ?? moment().add('15', 'minutes').toDate(),
        userType,
        token: `${moment().unix()}-${crypto.randomBytes(TOKEN_LENGTH).toString('hex')}`,
      }),
    );
  }

  findByToken(token: string, userType: UserType) {
    return this.userTokenRepository.findOne({ where: { token, isUsed: false, userType } });
  }

  invalidateToken(token: string) {
    return this.userTokenRepository.update({ token }, { isUsed: true });
  }
}
