import { BadRequestException, Injectable, Logger } from '@nestjs/common';
import { UserType } from '../enums';
import { UserTokenRepository } from '../repositories/user-token-repository';

@Injectable()
export class UserTokenService {
  constructor(private readonly userTokenRepository: UserTokenRepository) {}
  private readonly logger = new Logger(UserTokenService.name);

  async generateToken(userId: string, userType: UserType, expiryDate?: Date): Promise<string> {
    this.logger.log(`Generating token for user ${userId}`);
    const tokenEntity = await this.userTokenRepository.generateToken(userId, userType, expiryDate);
    this.logger.log(`Token generated successfully for junior ${userId}`);
    return tokenEntity.token;
  }

  async validateToken(token: string, userType: UserType): Promise<string> {
    this.logger.log(`Validating token ${token}`);
    const tokenEntity = await this.userTokenRepository.findByToken(token, userType);

    if (!tokenEntity) {
      this.logger.error(`Token ${token} not found`);
      throw new BadRequestException('TOKEN.INVALID');
    }

    if (tokenEntity.expiryDate < new Date()) {
      this.logger.error(`Token ${token} expired`);
      throw new BadRequestException('TOKEN.EXPIRED');
    }

    this.logger.log(`Token validated successfully`);
    return tokenEntity.juniorId! || tokenEntity.userId!;
  }

  invalidateToken(token: string) {
    this.logger.log(`Invalidating token ${token}`);
    return this.userTokenRepository.invalidateToken(token);
  }
}
